==> cuery-0.1-bin.tar.gz: cuery-0.1/src/java/org/trix/cuery/value/CSSURI.java <==
/*
 * Copyright 2004-2005 The Trix Development Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trix.cuery.value;

/**
 * DOCUMENT.
 * 
 * @author <a href="mailto:Teletha.T@gmail.com">Teletha Testarossa</a>
 * @version $ Id: CSSURI.java,v 1.0 2005/08/09 22:06:04 Teletha Exp $
 */
public class CSSURI extends AbstractValue {

    /**
     * Create CSSURI instance.
     * 
     * @param uri A uri value.
     * @param previous A previous value of this value.
     */
    public CSSURI(String uri, Value previous) {
        super(previous);

        this.stringValue = uri;
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getLexicalUnitType()
     */
    public short getLexicalUnitType() {
        return SAC_URI;
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getFloatValue()
     */
    public float getFloatValue() {
        throw new UnsupportedOperationException(getClass().getSimpleName() + " can't execute this method.");
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getStringValue()
     */
    public String getStringValue() {
        return stringValue;
    }

    /**
     * @see org.w3c.dom.css.CSSPrimitiveValue#getPrimitiveType()
     */
    public short getPrimitiveType() {
        return CSS_URI;
    }

    /**
     * @see org.trix.cuery.value.AbstractValue#getCssText()
     */
    @Override
    public String getCssText() {
        return "url(\"" + stringValue + "\")";
    }
}

==> cuery-0.4-bin.tar.gz: cuery-0.4/src/java/org/trix/cuery/value/CSSURI.java <==
/*
 * Copyright 2004-2005 The Trix Development Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trix.cuery.value;

/**
 * DOCUMENT.
 * 
 * @author <a href="mailto:Teletha.T@gmail.com">Teletha Testarossa</a>
 * @version $ Id: CSSURI.java,v 1.0 2005/08/09 22:06:04 Teletha Exp $
 */
public class CSSURI extends AbstractCSSValue {

    /**
     * Create CSSURI instance.
     * 
     * @param uri A uri value.
     * @param previous A previous value of this value.
     */
    public CSSURI(String uri, CSSValue previous) {
        super(previous);

        this.stringValue = uri;
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getLexicalUnitType()
     */
    public short getLexicalUnitType() {
        return SAC_URI;
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getFloatValue()
     */
    public float getFloatValue() {
        throw new UnsupportedOperationException(getClass() + " can't execute this method.");
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getStringValue()
     */
    public String getStringValue() {
        return stringValue;
    }

    /**
     * @see org.w3c.dom.css.CSSPrimitiveValue#getPrimitiveType()
     */
    public short getPrimitiveType() {
        return CSS_URI;
    }

    /**
     * @see org.trix.cuery.value.AbstractCSSValue#getCssText()
     */
    public String getCssText() {
        return "url(\"" + stringValue + "\")";
    }
}
